@@ -67,3 +67,6 @@ def output_file_list_to_excel(dir_path):
 @instruction
 def add_line_by_type(add_line_dict: dict, file_path, file_type='.py', output_path=r'add_line'):
     pofile.add_line_by_type(add_line_dict, file_path, file_type, output_path)
+@instruction
+def group_by_name(path):
+    pofile.group_by_name(path)
\ No newline at end of file
